package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.pkcs.DHParameter;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.PrivateKeyInfo;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.crypto.params.DHPrivateKeyParameters;
import cn.com.infosec.jce.interfaces.PKCS12BagAttributeCarrier;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.math.BigInteger;
import java.util.Enumeration;
import javax.crypto.interfaces.DHPrivateKey;
import javax.crypto.spec.DHParameterSpec;
import javax.crypto.spec.DHPrivateKeySpec;

public class JCEDHPrivateKey implements DHPrivateKey, PKCS12BagAttributeCarrier {
   static final long serialVersionUID = 311058815616901812L;
   BigInteger x;
   DHParameterSpec dhSpec;
   private PKCS12BagAttributeCarrier attrCarrier;

   protected JCEDHPrivateKey() {
      JCEDHPrivateKey var10000 = this;
      super();
      PKCS12BagAttributeCarrierImpl var1;
      var1 = new PKCS12BagAttributeCarrierImpl.<init>();
      var10000.attrCarrier = var1;
   }

   JCEDHPrivateKey(DHPrivateKey key) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = key.getX();
      this.dhSpec = key.getParams();
   }

   JCEDHPrivateKey(DHPrivateKeySpec spec) {
      JCEDHPrivateKey var10000 = this;
      super();
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = spec.getX();
      BigInteger var2 = spec.getP();
      var10000.dhSpec = new DHParameterSpec(var2, spec.getG());
   }

   JCEDHPrivateKey(PrivateKeyInfo info) {
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      DHParameter var2;
      var2 = new DHParameter.<init>((ASN1Sequence)info.getAlgorithmId().getParameters());
      this.x = ((DERInteger)info.getPrivateKey()).getValue();
      JCEDHPrivateKey var10000;
      BigInteger info1;
      if (var2.getL() != null) {
         var10000 = this;
         BigInteger var3 = var2.getP();
         info1 = var2.getG();
         var10000.dhSpec = new DHParameterSpec(var3, info1, var2.getL().intValue());
      } else {
         var10000 = this;
         DHParameterSpec var4;
         DHParameterSpec var10001 = var4 = new DHParameterSpec;
         info1 = var2.getP();
         var10001.<init>(info1, var2.getG());
         var10000.dhSpec = var4;
      }

   }

   JCEDHPrivateKey(DHPrivateKeyParameters params) {
      JCEDHPrivateKey var10000 = this;
      super();
      this.attrCarrier = new PKCS12BagAttributeCarrierImpl();
      this.x = params.getX();
      BigInteger var10003 = params.getParameters().getP();
      BigInteger var2 = params.getParameters().getG();
      var10000.dhSpec = new DHParameterSpec(var10003, var2, params.getParameters().getL());
   }

   private void readObject(ObjectInputStream in) {
      JCEDHPrivateKey var10000 = this;
      this.x = (BigInteger)in.readObject();
      ObjectInputStream var10003 = in;
      BigInteger var3 = (BigInteger)in.readObject();
      BigInteger in1 = (BigInteger)in.readObject();
      int var2 = var10003.readInt();
      var10000.dhSpec = new DHParameterSpec(var3, in1, var2);
   }

   private void writeObject(ObjectOutputStream out) {
      out.writeObject(this.getX());
      out.writeObject(this.dhSpec.getP());
      out.writeObject(this.dhSpec.getG());
      out.writeInt(this.dhSpec.getL());
   }

   public String getAlgorithm() {
      return "DH";
   }

   public String getFormat() {
      return "PKCS#8";
   }

   public byte[] getEncoded() {
      DERObjectIdentifier var10004 = PKCSObjectIdentifiers.dhKeyAgreement;
      BigInteger var10007 = this.dhSpec.getP();
      BigInteger var1 = this.dhSpec.getG();
      return (new PrivateKeyInfo(new AlgorithmIdentifier(var10004, (new DHParameter(var10007, var1, this.dhSpec.getL())).getDERObject()), new DERInteger(this.getX()))).getDEREncoded();
   }

   public DHParameterSpec getParams() {
      return this.dhSpec;
   }

   public BigInteger getX() {
      return this.x;
   }

   public void setBagAttribute(DERObjectIdentifier oid, DEREncodable attribute) {
      this.attrCarrier.setBagAttribute(oid, attribute);
   }

   public DEREncodable getBagAttribute(DERObjectIdentifier oid) {
      return this.attrCarrier.getBagAttribute(oid);
   }

   public Enumeration getBagAttributeKeys() {
      return this.attrCarrier.getBagAttributeKeys();
   }
}
